==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/RingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingDescriptionMetadata } from "./RingDescriptionMetadata";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { RingSeriesDescription } from "./RingSeriesDescription";
/**
 * @hidden
 */
var RingSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RingSeriesDescriptionMetadata, _super);
    function RingSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RingSeriesDescriptionMetadata.b = function (a) {
        if (RingSeriesDescriptionMetadata.a == null) {
            RingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RingSeriesDescriptionMetadata.c(RingSeriesDescriptionMetadata.a);
        }
        if (a.g(RingSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(RingSeriesDescriptionMetadata.a);
        RingDescriptionMetadata.d(a);
    };
    RingSeriesDescriptionMetadata.c = function (a) {
        RingSeriesBaseDescriptionMetadata.c(a);
        a.item("Ring", "ExportedType:Ring");
    };
    RingSeriesDescriptionMetadata.d = function (a) {
        RingSeriesDescriptionMetadata.b(a);
        a.u("RingSeries", function () { return new RingSeriesDescription(); });
        a.t("RingSeries", RingSeriesDescriptionMetadata.a);
    };
    RingSeriesDescriptionMetadata.$t = markType(RingSeriesDescriptionMetadata, 'RingSeriesDescriptionMetadata');
    RingSeriesDescriptionMetadata.a = null;
    return RingSeriesDescriptionMetadata;
}(Base));
export { RingSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RingSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RingDescriptionMetadata } from "./RingDescriptionMetadata";
import { RingSeriesBaseDescriptionMetadata } from "./RingSeriesBaseDescriptionMetadata";
import { RingSeriesDescription } from "./RingSeriesDescription";
/**
 * @hidden
 */
var RingSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RingSeriesDescriptionMetadata, _super);
    function RingSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RingSeriesDescriptionMetadata.b = function (a) {
        if (RingSeriesDescriptionMetadata.a == null) {
            RingSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RingSeriesDescriptionMetadata.c(RingSeriesDescriptionMetadata.a);
        }
        if (a.j(RingSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(RingSeriesDescriptionMetadata.a);
        RingDescriptionMetadata.d(a);
    };
    RingSeriesDescriptionMetadata.c = function (a) {
        RingSeriesBaseDescriptionMetadata.c(a);
        a.item("Ring", "ExportedType:Ring");
    };
    RingSeriesDescriptionMetadata.d = function (a) {
        RingSeriesDescriptionMetadata.b(a);
        a.aa("RingSeries", function () { return new RingSeriesDescription(); });
        a.z("RingSeries", RingSeriesDescriptionMetadata.a);
    };
    RingSeriesDescriptionMetadata.$t = markType(RingSeriesDescriptionMetadata, 'RingSeriesDescriptionMetadata');
    RingSeriesDescriptionMetadata.a = null;
    return RingSeriesDescriptionMetadata;
}(Base));
export { RingSeriesDescriptionMetadata };
